#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-static
version:              1.6.1.1
visibility:           public
id:                   yesod-static-1.6.1.1-KHcLQIOqvkH57HgeepZeqp
key:                  yesod-static-1.6.1.1-KHcLQIOqvkH57HgeepZeqp
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>

category:             Web, Yesod
abi:                  fcf07e987d7b820946b8a7829ab81de4
exposed:              True
exposed-modules:
    Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Css.AbsoluteUrl
    Yesod.EmbeddedStatic.Generators Yesod.EmbeddedStatic.Types
    Yesod.Static

hidden-modules:
    Yesod.EmbeddedStatic.Internal Yesod.EmbeddedStatic.Css.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/yesod-static-1.6.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yesod-static-1.6.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yesod-static-1.6.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-static
hs-libraries:         HSyesod-static-1.6.1.1-KHcLQIOqvkH57HgeepZeqp
depends:
    async-2.2.6-Gml4H6UctygFSqCTsp1iZf
    attoparsec-0.14.4-3CmiIm11iun2BHKDR4ovn7 base-4.18.2.1
    base64-bytestring-1.2.1.0-6zbb0o9xH9hLkYSzTxgmy9
    blaze-builder-0.4.4.1-4QmQvMAPyoDG7cxlUmp9Pw bytestring-0.11.5.3
    conduit-1.3.6.1-1yIrQJAoba7Gda6MAs4N1q containers-0.6.7
    crypton-1.0.4-BW3r2zHLDkn5MXOxLzl4Qy
    crypton-conduit-0.2.3-9HSt1xowpDXF3p1X6hD216
    css-text-0.1.3.0-9m1yjh6y74D3kHG18K7DTI
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    hashable-1.4.7.0-JuZCUcgZ6993MAquoa2cCW
    hjsmin-0.2.1-G6OByTSdMvyD47egQnnh2N
    http-types-0.12.4-4tdX51H3YCXI63KUlr8q5w
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    mime-types-0.1.2.1-1xtxegTvlKyFu1aTXaUpBN process-1.6.19.0
    template-haskell-2.20.0.0 text-2.0.2 transformers-0.6.1.0
    unix-compat-0.7.4.1-D5z0oaVDOHE7a26PpKdQ2K
    unordered-containers-0.2.20.1-24qNbjJ9xXJll0vtFCYfq
    wai-3.2.4-4nidytGQQ7OHwip6f8eKmG
    wai-app-static-3.1.9-5bCgDdmkAgbAkpKRSBQarx
    yesod-core-1.6.27.1-8sgJeSBtH3a2XhNRpRhgVW

haddock-interfaces:
    /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock

haddock-html:         /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

